==> libssh-docs-0.11.3-1-x86_64.pkg.tar.zst: usr/share/doc/libssh/html/search/all_11.js <==
var searchData=
[
  ['get_20the_20remote_20data_0',['A more elaborate way to get the remote data',['../libssh_tutor_shell.html#select_loop',1,'']]],
  ['getauthlist_1',['getAuthList',['../classssh_1_1Session.html#a08d70b5cdb5bd1a2a8f5f9ebbdf67b3b',1,'ssh::Session']]],
  ['getcode_2',['getCode',['../classssh_1_1SshException.html#a3f736fef0b7dbf062d11f64aa41a61f4',1,'ssh::SshException']]],
  ['getdisconnectmessage_3',['getDisconnectMessage',['../classssh_1_1Session.html#a60c2c49f3f89cd5cdccbad0f9c0fae07',1,'ssh::Session']]],
  ['geterror_4',['getError',['../classssh_1_1SshException.html#a712f65602f9ae8bc6737ed4b1e4ee4cc',1,'ssh::SshException']]],
  ['getissuebanner_5',['getIssueBanner',['../classssh_1_1Session.html#a9969ed8dcaccef321ac519271758b406',1,'ssh::Session']]],
  ['getopensshversion_6',['getOpensshVersion',['../classssh_1_1Session.html#a9e0af590062a73a0927bb513bc19dd8e',1,'ssh::Session']]],
  ['getsocket_7',['getSocket',['../classssh_1_1Session.html#a30c021f6138124d785f151583e5656bd',1,'ssh::Session']]],
  ['getting_20the_20banner_8',['Getting the banner',['../libssh_tutor_authentication.html#banner',1,'']]],
  ['getting_20the_20list_20of_20supported_20authentications_9',['Getting the list of supported authentications',['../libssh_tutor_authentication.html#auth_list',1,'']]],
  ['getversion_10',['getVersion',['../classssh_1_1Session.html#a5d7b4df57ed97f2592893b0493336b88',1,'ssh::Session']]],
  ['global_5frequest_5ffunction_11',['global_request_function',['../structssh__callbacks__struct.html#affa000c51d64fb6bb10c1ab7109ab1f1',1,'ssh_callbacks_struct']]],
  ['graphical_20applications_20on_20the_20remote_20side_12',['Using graphical applications on the remote side',['../libssh_tutor_shell.html#x11',1,'']]],
  ['gssapi_5faccept_5fsec_5fctx_5ffunction_13',['gssapi_accept_sec_ctx_function',['../structssh__server__callbacks__struct.html#a14030ebc1ed211eb66ba513812729db3',1,'ssh_server_callbacks_struct']]],
  ['gssapi_5fselect_5foid_5ffunction_14',['gssapi_select_oid_function',['../structssh__server__callbacks__struct.html#aecc399daa70f5595d6e921f58f93e7f0',1,'ssh_server_callbacks_struct']]]
];

==> libssh-docs-0.12.0-1.1-x86_64.pkg.tar.zst: usr/share/doc/libssh/html/search/all_11.js <==
var searchData=
[
  ['get_20the_20remote_20data_0',['A more elaborate way to get the remote data',['../libssh_tutor_shell.html#select_loop',1,'']]],
  ['getauthlist_1',['getAuthList',['../classssh_1_1Session.html#a08d70b5cdb5bd1a2a8f5f9ebbdf67b3b',1,'ssh::Session']]],
  ['getcode_2',['getCode',['../classssh_1_1SshException.html#a3f736fef0b7dbf062d11f64aa41a61f4',1,'ssh::SshException']]],
  ['getdisconnectmessage_3',['getDisconnectMessage',['../classssh_1_1Session.html#a60c2c49f3f89cd5cdccbad0f9c0fae07',1,'ssh::Session']]],
  ['geterror_4',['getError',['../classssh_1_1SshException.html#a712f65602f9ae8bc6737ed4b1e4ee4cc',1,'ssh::SshException']]],
  ['getissuebanner_5',['getIssueBanner',['../classssh_1_1Session.html#a9969ed8dcaccef321ac519271758b406',1,'ssh::Session']]],
  ['getopensshversion_6',['getOpensshVersion',['../classssh_1_1Session.html#a9e0af590062a73a0927bb513bc19dd8e',1,'ssh::Session']]],
  ['getsocket_7',['getSocket',['../classssh_1_1Session.html#a30c021f6138124d785f151583e5656bd',1,'ssh::Session']]],
  ['getting_20the_20banner_8',['Getting the banner',['../libssh_tutor_authentication.html#banner',1,'']]],
  ['getting_20the_20list_20of_20supported_20authentications_9',['Getting the list of supported authentications',['../libssh_tutor_authentication.html#auth_list',1,'']]],
  ['getversion_10',['getVersion',['../classssh_1_1Session.html#a5d7b4df57ed97f2592893b0493336b88',1,'ssh::Session']]],
  ['global_5frequest_5ffunction_11',['global_request_function',['../structssh__callbacks__struct.html#affa000c51d64fb6bb10c1ab7109ab1f1',1,'ssh_callbacks_struct']]],
  ['graphical_20applications_20on_20the_20remote_20side_12',['Using graphical applications on the remote side',['../libssh_tutor_shell.html#x11',1,'']]],
  ['gssapi_5faccept_5fsec_5fctx_5ffunction_13',['gssapi_accept_sec_ctx_function',['../structssh__server__callbacks__struct.html#a14030ebc1ed211eb66ba513812729db3',1,'ssh_server_callbacks_struct']]],
  ['gssapi_5fselect_5foid_5ffunction_14',['gssapi_select_oid_function',['../structssh__server__callbacks__struct.html#aecc399daa70f5595d6e921f58f93e7f0',1,'ssh_server_callbacks_struct']]],
  ['gssapi_5fverify_5fmic_5ffunction_15',['gssapi_verify_mic_function',['../structssh__server__callbacks__struct.html#a271c182e9599871b35a3dec984b6df47',1,'ssh_server_callbacks_struct']]]
];
